Easy Interface to the SDIF Sound Description Interchange Format Download (IRCAM, Analyse/Synthèse)

# Easdif -- Download
The Easy Interface to the SDIF Sound Description Interchange Format

Copyright (C) 2003 Analyse/Synthèse
Tuesday, 03-Jan-2006 15:01:50 CET

Axel Röbel, Xavier Rodet, Diemo Schwarz.

This page's URL: http://www.ircam.fr/sdif/download/Easdif
README
AUTHORS
COPYING
INSTALL
ChangeLog
Version 1.2.2b released 03.01.2006:
Easdif-1.2.2b-SDIF-3.10.2-src.tar.gz
Easdif-1.2.2b.doc.tgz
Version 0.8.1 released 02.02.2004:
Easdif-0.8.1-SDIF-3.8.0-src.tar.gz
Easdif-0.8.1.doc.tgz
Version 0.3.2 released 09.04.2003:
Easdif-0.3.2-SDIF-3.7.3-src.tar.gz
Easdif-0.3.2.doc.tgz

SDIF is a registered trademark, registered September 23, 1999 at INPI (Institut National de la Proprieté Industrielle), Paris, France for IRCAM - Centre Georges Pompidou, registration number 99/814815.